==> dcoupon_sdk_flutter_package-4.0.1.tar.gz: lib/src/utils/constants.dart <==
/// @author: jvrodrigo

enum AuthMethod { SIGNATURE, JWT }

enum ClientType { RETAILER, COMPANY, PUBLISHER }

class Constants {
  static const String CHANNEL_NAME_HTTP = "dcoupon_sdk_channel_http";
  static const String CHANNEL_NAME_VIEW = "dcoupon_sdk_channel_view";

  // Services Headers
  static const String HEADER_AUTH_APIKEY = "dcoupon-authorization-apikey";
  static const String HEADER_AUTH_SIGNATURE = "dcoupon-authorization-signature";
  static const String HEADER_AUTH_METHOD = "dcoupon-authorization-method";
  static const String HEADER_AUTH_TIMESTAMP = "dcoupon-authorization-timestamp";
  static const String HEADER_USER_JWT = "dcoupon-user-jwt";

  static const String HEADER_CLIENT_TYPE = "client-type";
  static const String HEADER_LOCATION = "location";

  // services
  static const String THIRD_PARTY_LOGIN = "login";
  static const String THIRD_PARTY_ENROLLMENT_FORM = "enrollmentform";
  static const String THIRD_PARTY_ACCEPT_ENROLLMENT = "acceptenrollment";

  static const String USER_COUPONS = "userCoupons";
  static const String USER_COUPON = "userCoupon";
  static const String USER_REDEMPTION_CODE = "redemptionCode";
  static const String USER_COUPON_ACTIVATE = "activateCoupon";
  static const String USER_COUPON_DEACTIVATE = "deactivateCoupon";
  static const String USER_COUPON_CREATE = "createCoupons";
  static const String USER_COUPONS_COMPANIES = "couponsCompanies";
  static const String USER_COUPONS_RETAILERS = "couponsRetailers";
  static const String USER_REDEMPTION_DETAIL = "redemptionDetail";
  static const String USER_REDEMPTION_HISTORY = "redemptionHistory";
  static const String USER_REDEMPTION_SUMMARY = "redemptionSummary";
  static const String USER_LOYALTY_CARD_LIST = "loyaltyCardList";
  static const String USER_LOYALTY_CARD_ADD_UPDATE = "loyaltyCardAddUpdate";
  static const String USER_LOYALTY_CARD_DELETE = "loyaltyCardDelete";
  static const String USER_LOYALTY_AFFILIATES = "loyaltyAffiliates";
  static const String USER_DATA_DETAIL = "userDataDetail";
  static const String USER_DATA_UPDATE = "userDataUpdate";

  static const String PUBLISHER_CATEGORIES = "publisherCategories";
  static const String PUBLISHER_COMPANIES = "publisherCompanies";
  static const String PUBLISHER_RETAILERS = "publisherRetailers";
  static const String PUBLISHER_PROMOTIONS = "publisherPromotions";
  static const String PUBLISHER_PROMOTION = "publisherPromotion";
  static const String PUBLISHER_STORES = "publisherStores";

  // custom
  static const String CLIENT_API_TOKEN = "clientApiToken";
  static const String CLIENT_SECRET_KEY = "clientSecretKey";
  static const String CLIENT_TYPE = "clienType";
  static const String CLIENT_COUNTRY = "clientCountry";
  static const String CLIENT_DOMAIN = "clientDomain";
  static const String TRUE = "true";
  static const String FALSE = "false";
  static const String OK = "OK";
  static const String ERROR = "ERROR";
  static const String REQUEST_TIMEOUT = "Request timeout";
  static const String JWT = "jwt";
  static const String METHOD = "method";
  static const String SEPARATOR = ",";
  static const String SDK = "SDK";
  static const String NOT_IMPLEMENTED = "Not implemented";

  // parameters interface for services
  static const String URL_REDIRECT = "urlRedirect";
  static const String EMAIL = "email";
  static const String EXTERNAL_ID = "externalId";
  static const String REFERRAL_CODE = "referralCode";
  static const String ALIAS = "alias";
  static const String GENDER = "gender";
  static const String BIRTHDATE = "birthdate";
  static const String MALE = "MALE";
  static const String FEMALE = "FEMALE";
  static const String OTHER = "OTHER";
  static const String RATHER_NOT_SAY = "RATHERNOTSAY";
  static const String LEGAL_DOCUMENTS_ACCEPTED = "legalDocumentsAccepted";
  static const String CLIENT_TYPE_RETAILER = "RETAILER";
  static const String CLIENT_TYPE_COMPANY = "COMPANY";
  static const String CLIENT_TYPE_PUBLISHER = "PUBLISHER";
  static const String COUPON_DETAIL_LIST = "couponDetailList";
  static const String CONTENT_TYPE = "Content-Type";
  static const String JSON_UTF_8 = "application/json; charset=UTF-8";
  static const String FORM = "form";
  static const String LEGAL_DOCUMENTS = "legalDocuments";
  static const String DOC_TYPE = "docType";
  static const String DOC_UUID = "docUuid";
  static const String DEFAULT_LANG = "defaultLang";
  static const String CONTENT = "content";
  static const String LEGAL_DOC = "legalDoc";
  static const String PP = "pp";
  static const String TOU = "tou";
  static const String USER = "user";
  static const String PUBLISHER_ID = "publisherId";
  static const String PUBLISHER_TOKEN = "publisherToken";
  static const String API_TOKEN_PUBLISHER = "apiTokenPublisher";
  static const String OFFSET = "offset";
  static const String START = "start";
  static const String LIMIT = "limit";
  static const String SORT_BY = "sortBy";
  static const String GROUP_BY = "groupBy";
  static const String CATEGORY_IDS = "categoryIds";
  static const String STORE_IDS = "storeIds";
  static const String LONGITUDE = "longitude";
  static const String LATITUDE = "latitude";
  static const String PROMOTION_TOKEN = "promotionToken";
  static const String PROMO_TOKENS = "promoTokens";
  static const String ZIPCODE = "zipcode";
  static const String RADIUS = "radius";
  static const String RETAILER_TOKENS = "retailerTokens";
  static const String COMPANY_TOKENS = "companyTokens";
  static const String COUNTRY = "country";
  static const String SIGNATURE_VALUE = "signatureValue";
  static const String DATETIME = "datetime";
  static const String LANG = "lang";
  static const String PATH_PARAMETER = "pathParameter";
  static const String META_COUPON_TOKENS = "metaCouponTokens";
  static const String API_TOKEN_META_COUPON = "apiTokenMetaCoupon";
  static const String UCUPON_TYPE = "ucuponType";
  static const String CREATION_LONGITUDE = "creationLongitude";
  static const String SOURCE = "source";
  static const String CREATION_LATITUDE = "creationLatitude";
  static const String TRANS_ID = "transId";
  static const String CRM_ID = "crmId";
  static const String TEXT_SEARCH = "textSearch";
  static const String ORDER_BY = "orderBy";
  static const String FILTERS_CATEGORIES = "filtersCategories";
  static const String FILTERS_COMPANIES = "filtersCompanies";
  static const String FILTERS_RETAILERS = "filtersRetailers";
  static const String GENERIC_RESPONSE = "genericResponse";
  static const String RESPONSE_MSG = "responseMsg";
  static const String REDEMPTION_ID = "redemptionID";
  static const String INITIAL_DATE = "initialDate";
  static const String END_DATE = "endDate";
  static const String GMT_TIME_ZONE_OFFSET = "gmtTimeZoneOffset";
  static const String API_TOKEN_AFFILIATE = "apiTokenAffiliate";
  static const String CARD_NUMBER = "cardNumber";
  static const String USER_DATA = "UserData";
}

==> dcoupon_sdk_flutter_package-4.3.0.tar.gz: lib/src/utils/constants.dart <==
/// @author: jvrodrigo

enum AuthMethod { SIGNATURE, JWT }

enum ClientType { RETAILER, COMPANY, PUBLISHER, DCOUPON }

class Constants {
  static const String CHANNEL_NAME_HTTP = "dcoupon_sdk_channel_http";
  static const String CHANNEL_NAME_VIEW = "dcoupon_sdk_channel_view";

  // Services Headers
  static const String HEADER_AUTH_APIKEY = "dcoupon-authorization-apikey";
  static const String HEADER_AUTH_SIGNATURE = "dcoupon-authorization-signature";
  static const String HEADER_AUTH_METHOD = "dcoupon-authorization-method";
  static const String HEADER_AUTH_TIMESTAMP = "dcoupon-authorization-timestamp";
  static const String HEADER_USER_JWT = "dcoupon-user-jwt";

  static const String HEADER_CLIENT_TYPE = "client-type";
  static const String HEADER_LOCATION = "location";

  // services
  static const String THIRD_PARTY_LOGIN = "login";
  static const String THIRD_PARTY_ENROLLMENT_FORM = "enrollmentform";
  static const String THIRD_PARTY_ACCEPT_ENROLLMENT = "acceptenrollment";

  static const String USER_COUPONS = "userCoupons";
  static const String USER_COUPON = "userCoupon";
  static const String USER_REDEMPTION_CODE = "redemptionCode";
  static const String USER_COUPON_ACTIVATE = "activateCoupon";
  static const String USER_COUPON_DEACTIVATE = "deactivateCoupon";
  static const String USER_COUPON_CREATE = "createCoupons";
  static const String USER_COUPONS_COMPANIES = "couponsCompanies";
  static const String USER_COUPONS_RETAILERS = "couponsRetailers";
  static const String USER_REDEMPTION_DETAIL = "redemptionDetail";
  static const String USER_REDEMPTION_HISTORY = "redemptionHistory";
  static const String USER_REDEMPTION_SUMMARY = "redemptionSummary";
  static const String USER_LOYALTY_CARD_LIST = "loyaltyCardList";
  static const String USER_LOYALTY_CARD_ADD_UPDATE = "loyaltyCardAddUpdate";
  static const String USER_LOYALTY_CARD_DELETE = "loyaltyCardDelete";
  static const String USER_LOYALTY_AFFILIATES = "loyaltyAffiliates";
  static const String USER_DATA_DETAIL = "userDataDetail";
  static const String USER_DATA_UPDATE = "userDataUpdate";

  static const String PUBLISHER_CATEGORIES = "publisherCategories";
  static const String PUBLISHER_COMPANIES = "publisherCompanies";
  static const String PUBLISHER_RETAILERS = "publisherRetailers";
  static const String PUBLISHER_PROMOTIONS = "publisherPromotions";
  static const String PUBLISHER_PROMOTION = "publisherPromotion";
  static const String PUBLISHER_STORES = "publisherStores";

  // custom
  static const String CLIENT_API_TOKEN = "clientApiToken";
  static const String CLIENT_SECRET_KEY = "clientSecretKey";
  static const String CLIENT_TYPE = "clienType";
  static const String CLIENT_COUNTRY = "clientCountry";
  static const String CLIENT_DOMAIN = "clientDomain";
  static const String TRUE = "true";
  static const String FALSE = "false";
  static const String OK = "OK";
  static const String ERROR = "ERROR";
  static const String REQUEST_TIMEOUT = "Request timeout";
  static const String JWT = "jwt";
  static const String METHOD = "method";
  static const String SEPARATOR = ",";
  static const String SDK = "SDK";
  static const String NOT_IMPLEMENTED = "Not implemented";

  // parameters interface for services
  static const String URL_REDIRECT = "urlRedirect";
  static const String EMAIL = "email";
  static const String EXTERNAL_ID = "externalId";
  static const String REFERRAL_CODE = "referralCode";
  static const String ALIAS = "alias";
  static const String GENDER = "gender";
  static const String BIRTHDATE = "birthdate";
  static const String MALE = "MALE";
  static const String FEMALE = "FEMALE";
  static const String OTHER = "OTHER";
  static const String RATHER_NOT_SAY = "RATHERNOTSAY";
  static const String LEGAL_DOCUMENTS_ACCEPTED = "legalDocumentsAccepted";
  static const String LEGAL_DOCS_IDS = "legalDocsIds";
  static const String CLIENT_TYPE_RETAILER = "RETAILER";
  static const String CLIENT_TYPE_COMPANY = "COMPANY";
  static const String CLIENT_TYPE_PUBLISHER = "PUBLISHER";
  static const String COUPON_DETAIL_LIST = "couponDetailList";
  static const String CONTENT_TYPE = "Content-Type";
  static const String JSON_UTF_8 = "application/json; charset=UTF-8";
  static const String SESSION_TOKEN = "sessionToken";
  static const String FORM = "form";
  static const String LEGAL_DOCUMENTS = "legalDocuments";
  static const String DOC_ID = "id";
  static const String DOC_TYPE = "type";
  static const String DOC_VERSION = "version";
  static const String DOC_CONTENT = "content";
  static const String DOC_DEFAULT_LANGUAGE = "defaultLanguage";
  static const String DOC_VERSION_CHANGES = "versionChanges";
  static const String DOC_LEGAL_DOC = "legalDoc";
  static const String PP = "pp";
  static const String TOU = "tou";
  static const String USER = "user";
  static const String PUBLISHER_ID = "publisherId";
  static const String PUBLISHER_TOKEN = "publisherToken";
  static const String API_TOKEN_PUBLISHER = "apiTokenPublisher";
  static const String OFFSET = "offset";
  static const String START = "start";
  static const String LIMIT = "limit";
  static const String SORT_BY = "sortBy";
  static const String GROUP_BY = "groupBy";
  static const String CATEGORY_IDS = "categoryIds";
  static const String STORE_IDS = "storeIds";
  static const String LONGITUDE = "longitude";
  static const String LATITUDE = "latitude";
  static const String PROMOTION_TOKEN = "promotionToken";
  static const String PROMO_TOKENS = "promoTokens";
  static const String ZIPCODE = "zipcode";
  static const String RADIUS = "radius";
  static const String RETAILER_TOKENS = "retailerTokens";
  static const String COMPANY_TOKENS = "companyTokens";
  static const String COUNTRY = "country";
  static const String SIGNATURE_VALUE = "signatureValue";
  static const String DATETIME = "datetime";
  static const String LANG = "lang";
  static const String PATH_PARAMETER = "pathParameter";
  static const String META_COUPON_TOKENS = "metaCouponTokens";
  static const String API_TOKEN_META_COUPON = "apiTokenMetaCoupon";
  static const String UCUPON_TYPE = "ucuponType";
  static const String CREATION_LONGITUDE = "creationLongitude";
  static const String PLATFORM = "platform";
  static const String SAVE_METHOD = "saveMethod";
  static const String SOURCE = "source";
  static const String CREATION_LATITUDE = "creationLatitude";
  static const String TRANS_ID = "transId";
  static const String CRM_ID = "crmId";
  static const String TEXT_SEARCH = "textSearch";
  static const String ORDER_BY = "orderBy";
  static const String FILTERS_CATEGORIES = "filtersCategories";
  static const String FILTERS_COMPANIES = "filtersCompanies";
  static const String FILTERS_RETAILERS = "filtersRetailers";
  static const String GENERIC_RESPONSE = "genericResponse";
  static const String RESPONSE_MSG = "responseMsg";
  static const String REDEMPTION_ID = "redemptionID";
  static const String INITIAL_DATE = "initialDate";
  static const String END_DATE = "endDate";
  static const String GMT_TIME_ZONE_OFFSET = "gmtTimeZoneOffset";
  static const String API_TOKEN_AFFILIATE = "apiTokenAffiliate";
  static const String CARD_NUMBER = "cardNumber";
  static const String USER_DATA = "UserData";
  static const String FORM_DATA = "formData";
}
